@@ -390,8 +390,6 @@ class RKXMLRequest(XMLRequest):
         for guid in self.get_visits():
             body = f'<RK7Query><RK7Command CMD="GetOrder"><Order guid="{guid}"/></RK7Command></RK7Query>'
             response = self.send_request(body=body)
-            file = open('data.txt', 'a')
-            file.write(str(response.text))
             parsed_collection = Etree.fromstring(response.content)
             for order in parsed_collection.findall('./CommandResult/Order'):
                 order_item = order.attrib
