@@ -126,6 +126,19 @@ class WaiterDTO(TypedDict):
     code: int
 
 
+class GetOrderDTO(TypedDict):
+    ident: int
+    guid: dict
+    dish_id: int
+    dish_name: str
+    quantity: int
+
+
+class GetVisitDTO(TypedDict):
+    order_id: int
+    guid: str
+
+
 class ConnectionErrors(Exception):
     pass
 
